# mpsmarthome
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.1
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mpsmarthome
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mpsmarthome
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import mpsmarthome
from mpsmarthome.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = mpsmarthome.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with mpsmarthome.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = mpsmarthome.HomeAssistantApi(api_client)
    auth_request = mpsmarthome.AuthRequest() # AuthRequest |  (optional)

    try:
        api_response = api_instance.api_homeassistant_authenticate_post(auth_request=auth_request)
        print("The response of HomeAssistantApi->api_homeassistant_authenticate_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling HomeAssistantApi->api_homeassistant_authenticate_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*HomeAssistantApi* | [**api_homeassistant_authenticate_post**](docs/HomeAssistantApi.md#api_homeassistant_authenticate_post) | **POST** /api/homeassistant/authenticate | 
*HomeAssistantApi* | [**api_homeassistant_full_post**](docs/HomeAssistantApi.md#api_homeassistant_full_post) | **POST** /api/homeassistant/full | 
*HomeAssistantApi* | [**api_homeassistant_meters_get**](docs/HomeAssistantApi.md#api_homeassistant_meters_get) | **GET** /api/homeassistant/meters | 
*HomeAssistantApi* | [**api_homeassistant_partial_post**](docs/HomeAssistantApi.md#api_homeassistant_partial_post) | **POST** /api/homeassistant/partial | 
*HomeyApi* | [**api_homey_authenticate_post**](docs/HomeyApi.md#api_homey_authenticate_post) | **POST** /api/homey/authenticate | 
*HomeyApi* | [**api_homey_full_post**](docs/HomeyApi.md#api_homey_full_post) | **POST** /api/homey/full | 
*HomeyApi* | [**api_homey_meters_get**](docs/HomeyApi.md#api_homey_meters_get) | **GET** /api/homey/meters | 
*HomeyApi* | [**api_homey_partial_post**](docs/HomeyApi.md#api_homey_partial_post) | **POST** /api/homey/partial | 


## Documentation For Models

 - [AuthRequest](docs/AuthRequest.md)
 - [AuthResponse](docs/AuthResponse.md)
 - [FullRequest](docs/FullRequest.md)
 - [MeterReadingData](docs/MeterReadingData.md)
 - [MeterReadingResponse](docs/MeterReadingResponse.md)
 - [MeterReadingResponseData](docs/MeterReadingResponseData.md)
 - [MetersResponse](docs/MetersResponse.md)
 - [PartialRequest](docs/PartialRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKey"></a>
### ApiKey

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author




